@@ -8,7 +8,7 @@ from pytype.typegraph import cfg
 import unittest
 
 
-class Node(object):
+class Node:
   """A graph node, for testing tree printing."""
 
   def __init__(self, name, *incoming):
@@ -29,7 +29,7 @@ class Node(object):
 class DebugTest(unittest.TestCase):
 
   def setUp(self):
-    super(DebugTest, self).setUp()
+    super().setUp()
     self.prog = cfg.Program()
     self.current_location = self.prog.NewCFGNode()
 
