@@ -12,7 +12,6 @@ from pytype import abstract_utils
 from pytype import mixin
 from pytype import overlay_utils
 from pytype import special_builtins
-import six
 
 
 log = logging.getLogger(__name__)
@@ -22,7 +21,7 @@ log = logging.getLogger(__name__)
 Param = overlay_utils.Param
 
 
-class Ordering(object):
+class Ordering:
   """Possible orderings for get_class_locals."""
   # Order by each variable's first annotation. For example, for
   #   class Foo:
@@ -43,20 +42,22 @@ class Ordering(object):
   LAST_ASSIGN = object()
 
 
-class Attribute(object):
+class Attribute:
   """Represents a class member variable.
 
   Members:
     name: field name
     typ: field python type
     init: Whether the field should be included in the generated __init__
+    kw_only: Whether the field is kw_only in the generated __init__
     default: Default value
   """
 
-  def __init__(self, name, typ, init, default):
+  def __init__(self, name, typ, init, kw_only, default):
     self.name = name
     self.typ = typ
     self.init = init
+    self.kw_only = kw_only
     self.default = default
 
   def __repr__(self):
@@ -64,8 +65,7 @@ class Attribute(object):
                 "default": self.default})
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Decorator(abstract.PyTDFunction):
+class Decorator(abstract.PyTDFunction, metaclass=abc.ABCMeta):
   """Base class for decorators that generate classes from data declarations."""
 
   # Defaults for the args that we support (dataclasses only support 'init',
@@ -77,7 +77,7 @@ class Decorator(abstract.PyTDFunction):
   }
 
   def __init__(self, *args, **kwargs):
-    super(Decorator, self).__init__(*args, **kwargs)
+    super().__init__(*args, **kwargs)
     # Decorator.call() is invoked first with args, then with the class to
     # decorate, so we need to first store the args and then associate them to
     # the right class.
@@ -103,27 +103,29 @@ class Decorator(abstract.PyTDFunction):
     return attr.name
 
   def make_init(self, node, cls, attrs):
-    attr_params = []
+    pos_params = []
+    kwonly_params = []
+    all_kwonly = self.args[cls]["kw_only"]
     for attr in attrs:
-      if attr.init:
-        # call self.init_name in case the name differs from the field name -
-        # e.g. attrs removes leading underscores from attrib names when
-        # generating kwargs for __init__.
-        attr_params.append(
-            Param(name=self.init_name(attr),
-                  typ=attr.typ,
-                  default=attr.default))
+      if not attr.init:
+        continue
+      # call self.init_name in case the name differs from the field name -
+      # e.g. attrs removes leading underscores from attrib names when
+      # generating kwargs for __init__.
+      param = Param(
+          name=self.init_name(attr),
+          typ=attr.typ,
+          default=attr.default)
 
-    # The kw_only arg is ignored in python2; using it is not an error.
-    if self.args[cls]["kw_only"] and self.vm.PY3:
-      params = []
-      kwonly_params = attr_params
-    else:
-      params = attr_params
-      kwonly_params = []
+      # The kw_only arg is ignored in python2; using it is not an error.
+      # kw_only=False in a field does not override kw_only=True in the class.
+      if self.vm.PY3 and (all_kwonly or attr.kw_only):
+        kwonly_params.append(param)
+      else:
+        pos_params.append(param)
 
-    return overlay_utils.make_method(self.vm, node, "__init__", params,
-                                     kwonly_params)
+    return overlay_utils.make_method(
+        self.vm, node, "__init__", pos_params, kwonly_params)
 
   def get_base_class_attrs(self, cls, cls_attrs, metadata_key):
     # Traverse the MRO and collect base class attributes. We only add an
@@ -144,6 +146,7 @@ class Decorator(abstract.PyTDFunction):
 
   def call(self, node, func, args):
     """Construct a decorator, and call it on the class."""
+    args = args.simplify(node, self.vm)
     self.match_args(node, args)
 
     # There are two ways to use a decorator:
