@@ -9,7 +9,6 @@ import collections
 
 from pytype import utils
 from pytype.pyi import parser
-from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.pytd import visitors
 
@@ -18,24 +17,19 @@ class UnrestorableDependencyError(Exception):
   """If a dependency can't be restored in the current state."""
 
 
-class FindClassAndFunctionTypesVisitor(visitors.Visitor):
+class FindClassTypesVisitor(visitors.Visitor):
   """Visitor to find class and function types."""
 
   def __init__(self):
     super().__init__()
     self.class_type_nodes = []
-    self.function_type_nodes = []
 
   def EnterClassType(self, n):
     self.class_type_nodes.append(n)
 
-  def EnterFunctionType(self, n):
-    self.function_type_nodes.append(n)
-
 
 SerializableTupleClass = collections.namedtuple(
-    "_", ["ast", "dependencies", "late_dependencies",
-          "class_type_nodes", "function_type_nodes"])
+    "_", ["ast", "dependencies", "late_dependencies", "class_type_nodes"])
 
 
 class SerializableAst(SerializableTupleClass):
@@ -81,15 +75,14 @@ def StoreAst(ast, filename=None, open_function=open):
 
   # Clean external references
   ast.Visit(visitors.ClearClassPointers())
-  indexer = FindClassAndFunctionTypesVisitor()
+  indexer = FindClassTypesVisitor()
   ast.Visit(indexer)
   ast = ast.Visit(visitors.CanonicalOrderingVisitor())
   return pytd_utils.SavePickle(
       SerializableAst(
           ast, sorted(dependencies.items()),
           sorted(late_dependencies.items()),
-          sorted(indexer.class_type_nodes),
-          sorted(indexer.function_type_nodes)),
+          sorted(indexer.class_type_nodes)),
       filename, open_function=open_function)
 
 
@@ -110,7 +103,7 @@ def EnsureAstName(ast, module_name, fix=False):
   # module_name is the name from this run, raw_ast.name is the guessed name from
   # when the ast has been pickled.
   if fix and module_name != raw_ast.name:
-    ast = ast.Replace(class_type_nodes=None, function_type_nodes=None)
+    ast = ast.Replace(class_type_nodes=None)
     ast = ast.Replace(ast=raw_ast.Visit(
         visitors.RenameModuleVisitor(raw_ast.name, module_name)))
   else:
@@ -186,18 +179,7 @@ def _LookupClassReferences(serializable_ast, module_map, self_name):
     except KeyError as e:
       raise UnrestorableDependencyError(
           "Unresolved class: %r." % utils.message(e)) from e
-  for node in (serializable_ast.function_type_nodes or ()):
-    try:
-      # Use VisitNamedType, even though this is a FunctionType. We want to
-      # do a name lookup, to make sure this is still a function.
-      if not isinstance(class_lookup.VisitNamedType(node), pytd.FunctionType):
-        serializable_ast = serializable_ast.Replace(function_type_nodes=None)
-        break
-    except KeyError as e:
-      raise UnrestorableDependencyError(
-          "Unresolved class: %r." % utils.message(e)) from e
-  if (serializable_ast.class_type_nodes is None or
-      serializable_ast.function_type_nodes is None):
+  if serializable_ast.class_type_nodes is None:
     try:
       raw_ast = raw_ast.Visit(class_lookup)
     except KeyError as e:
@@ -210,20 +192,14 @@ def _LookupClassReferences(serializable_ast, module_map, self_name):
 def FillLocalReferences(serializable_ast, module_map):
   """Fill in local references."""
   local_filler = visitors.FillInLocalPointers(module_map)
-  if (serializable_ast.class_type_nodes is None or
-      serializable_ast.function_type_nodes is None):
+  if serializable_ast.class_type_nodes is None:
     serializable_ast.ast.Visit(local_filler)
-    return serializable_ast.Replace(
-        class_type_nodes=None, function_type_nodes=None)
+    return serializable_ast.Replace(class_type_nodes=None)
   else:
     for node in serializable_ast.class_type_nodes:
       local_filler.EnterClassType(node)
       if node.cls is None:
         raise AssertionError("This should not happen: %s" % str(node))
-    for node in serializable_ast.function_type_nodes:
-      local_filler.EnterFunctionType(node)
-      if node.function is None:
-        raise AssertionError("This should not happen: %s" % str(node))
     return serializable_ast
 
 
