@@ -2,8 +2,9 @@
 
 import os
 
+from pytype import file_utils
+from pytype.pytd import builtins
 from pytype.pytd import typeshed
-from pytype.pytd.parse import builtins
 from pytype.pytd.parse import parser_test_base
 from pytype.tests import test_base
 
@@ -12,20 +13,20 @@ class TestTypeshedLoading(parser_test_base.ParserTest):
   """Test the code for loading files from typeshed."""
 
   def setUp(self):
-    super(TestTypeshedLoading, self).setUp()
+    super().setUp()
     self.ts = typeshed.Typeshed()
 
   def test_get_typeshed_file(self):
     filename, data = self.ts.get_module_file(
         "stdlib", "errno", self.python_version)
     self.assertEqual("errno.pyi", os.path.basename(filename))
-    self.assertIn(b"errorcode", data)
+    self.assertIn("errorcode", data)
 
   def test_get_typeshed_dir(self):
     filename, data = self.ts.get_module_file(
         "stdlib", "logging", self.python_version)
     self.assertEqual("__init__.pyi", os.path.basename(filename))
-    self.assertIn(b"LogRecord", data)
+    self.assertIn("LogRecord", data)
 
   def test_parse_type_definition(self):
     filename, ast = typeshed.parse_type_definition(
@@ -71,7 +72,7 @@ class TestTypeshedLoading(parser_test_base.ParserTest):
 
       paths = {p.rsplit("pytype/", 1)[-1]
                for p in self.ts.get_pytd_paths(self.python_version)}
-      self.assertSetEqual(paths, {"pytd/builtins/3", "pytd/stdlib/3"})
+      self.assertSetEqual(paths, {"stubs/builtins/3", "stubs/stdlib/3"})
     finally:
       os.environ = old_env
 
@@ -86,6 +87,22 @@ class TestTypeshedLoading(parser_test_base.ParserTest):
     for module_name in self.ts.blacklisted_modules([3, 6]):
       self.assertNotIn("/", module_name)
 
+  def test_carriage_return(self):
+    # _env_home is used in preference to _root, so make sure it's unset.
+    self.ts._env_home = None
+    with file_utils.Tempdir() as d:
+      d.create_file("stdlib/3/foo.pyi", b"x: int\r\n")
+      self.ts._root = d.path
+      _, src = self.ts.get_module_file("stdlib", "foo", (3, 8))
+    self.assertEqual(src, "x: int\n")
+
+  def test_carriage_return_custom_root(self):
+    with file_utils.Tempdir() as d:
+      d.create_file("stdlib/3/foo.pyi", b"x: int\r\n")
+      self.ts._env_home = d.path
+      _, src = self.ts.get_module_file("stdlib", "foo", (3, 8))
+    self.assertEqual(src, "x: int\n")
+
 
 class TestTypeshedParsing(test_base.TargetPython27FeatureTest):
   """Tests a handful of typeshed modules.
@@ -95,7 +112,7 @@ class TestTypeshedParsing(test_base.TargetPython27FeatureTest):
   """
 
   def setUp(self):
-    super(TestTypeshedParsing, self).setUp()
+    super().setUp()
     self.ConfigureOptions(module_name="base")
 
   def test_quopri(self):
