@@ -1,16 +1,14 @@
 """Use pytype to analyze and infer types for an entire project."""
 
-from __future__ import print_function
-
 import logging
 import os
 import subprocess
 import sys
+from typing import Iterable, Sequence, Tuple
 
 from pytype import file_utils
 from pytype import module_utils
 from pytype.tools.analyze_project import config
-import six
 
 
 # Generate a default pyi for builtin and system dependencies.
@@ -20,13 +18,13 @@ def __getattr__(name) -> Any: ...
 """
 
 
-class Action(object):
+class Action:
   CHECK = 'check'
   INFER = 'infer'
   GENERATE_DEFAULT = 'generate default'
 
 
-class Stage(object):
+class Stage:
   SINGLE_PASS = 'single pass'
   FIRST_PASS = 'first pass'
   SECOND_PASS = 'second pass'
@@ -35,17 +33,19 @@ class Stage(object):
 FIRST_PASS_SUFFIX = '-1'
 
 
-def _get_pytype_single_executable():
-  custom_bin = os.path.join('out', 'bin', 'pytype')
-  if sys.argv[0] == custom_bin:
-    # The Travis type-check step uses custom pytype binaries in pytype/out/bin/.
-    return [os.path.join(os.path.abspath(os.path.dirname(custom_bin)),
-                         'pytype-single')]
-  elif sys.executable is not None:
-    return [sys.executable, '-m', 'pytype.single']
+def _get_executable(binary, module=None):
+  """Get the path to the executable with the given name."""
+  if binary == 'pytype-single':
+    custom_bin = os.path.join('out', 'bin', 'pytype')
+    if sys.argv[0] == custom_bin:
+      # The Travis type-check step uses custom binaries in pytype/out/bin/.
+      return [os.path.join(os.path.abspath(os.path.dirname(custom_bin)),
+                           'pytype-single')]
+  if sys.executable is not None:
+    return [sys.executable, '-m', module or binary]
   else:
-    return ['pytype-single']
-PYTYPE_SINGLE = _get_pytype_single_executable()
+    return [binary]
+PYTYPE_SINGLE = _get_executable('pytype-single', 'pytype.single')
 
 
 def resolved_file_to_module(f):
@@ -74,7 +74,7 @@ def deps_from_import_graph(import_graph):
     List of (tuple of source modules, tuple of direct deps) in dependency order.
   """
   def get_filenames(node):
-    if isinstance(node, six.string_types):
+    if isinstance(node, str):
       return (node,)
     else:
       # Make the build as deterministic as possible to minimize rebuilds.
@@ -130,7 +130,7 @@ def get_imports_map(deps, module_to_imports_map, module_to_output):
   return imports_map
 
 
-class PytypeRunner(object):
+class PytypeRunner:
   """Runs pytype over an import graph."""
 
   def __init__(self, conf, sorted_sources):
@@ -230,7 +230,8 @@ class PytypeRunner(object):
       report('%s: %s module %s', action, module.kind, module.name)
     return action
 
-  def yield_sorted_modules(self):
+  def yield_sorted_modules(self) -> Iterable[
+      Tuple[module_utils.Module, str, Sequence[module_utils.Module], str]]:
     """Yield modules from our sorted source files."""
     for group, deps in self.sorted_sources:
       modules = []
@@ -239,7 +240,8 @@ class PytypeRunner(object):
         if action:
           modules.append((module, action))
       if len(modules) == 1:
-        yield modules[0] + (deps, Stage.SINGLE_PASS)
+        # TODO(b/73562531): Remove the pytype disable once the bug is fixed.
+        yield modules[0] + (deps, Stage.SINGLE_PASS)  # pytype: disable=bad-return-type
       else:
         # If we have a cycle we run pytype over the files twice. So that we
         # don't fail on missing dependencies, we'll ignore errors the first
@@ -347,10 +349,13 @@ class PytypeRunner(object):
     # -v       show all command lines while building
     k = '0' if self.keep_going else '1'
     c = os.path.dirname(self.ninja_file)
-    command = ['ninja', '-k', k, '-C', c, '-j', str(self.jobs)]
+    command = _get_executable('ninja') + [
+        '-k', k, '-C', c, '-j', str(self.jobs)]
     if logging.getLogger().isEnabledFor(logging.INFO):
       command.append('-v')
-    return subprocess.call(command)
+    ret = subprocess.call(command)
+    print('Leaving directory %r' % c)
+    return ret
 
   def run(self):
     """Run pytype over the project."""
